@@ -17,6 +17,7 @@ our @EXPORT = qw(
     HTTP_Request
     encode
     encode_data
+    json_data
     format_output
     %SERVICES
     $API_URL
@@ -26,13 +27,16 @@ our @EXPORT = qw(
 *encode = \&encode_data;
 
 # Set the package version. 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 # Load the required Perl modules or packages.
 use JSON::PP;
 use URI;
 use LWP::UserAgent;
 
+# Load the required modules.
+use CryptoTron::AddressCheck; 
+
 # Set api url and api path.
 our $API_URL = 'https://api.trongrid.io';
 
@@ -61,6 +65,43 @@ $JSON = $JSON->allow_unknown("true");
 $JSON = $JSON->allow_blessed("true");
 $JSON = $JSON->allow_singlequote("true");
 
+# ---------------------------------------------------------------------------- #
+# Function json_data()                                                         #
+# ---------------------------------------------------------------------------- #
+sub json_data {
+    # Assign the arguments to the local array.
+    my ($args) = @_;
+    # Set the local variables.
+    my $address = (defined $args->{PublicAddr} ? $args->{PublicAddr} : "");
+    my $outflag = (defined $args->{OutputFlag} ? $args->{OutputFlag} : "RAW");
+    my $visible = (defined $args->{VisibleSwitch} ? $args->{VisibleSwitch} : "True");
+    my $addrchk = (defined $args->{AddrCheck} ? $args->{AddrCheck} : "True");
+    # Get the name of the calling module.   
+    my $module_name = $args->{ModuleName};
+    # Get service url and related method.
+    my $service_url = $API_URL.$SERVICES{$module_name}[0];
+    my $method = $SERVICES{$module_name}[1];
+    # Initialise the local variables. 
+    my $payload = "";
+    my $content = "";
+    # Initialise the return variable.
+    my $output_data = "{}";
+    # Check if address is not empty.
+    if ($address ne "") {
+        # Check if address check is set to True.
+        $visible = (($visible eq "True" && chk_base58_addr($address) != 1) ? "False" : "True"); 
+        $visible = (($visible eq "False" && chk_hex_addr($address) != 1) ? "True" : "False"); 
+        # Create the payload from the address.
+        $payload = "\{\"address\":\"$address\",\"visible\":\"$visible\"\}";
+        # Get the content from the service url.
+        ($content, undef, undef, undef) = HTTP_Request($service_url, $method, $payload);
+        # Format the content for the output.
+        $output_data = format_output($content, $outflag);
+    };
+    # Return the JSON data raw or formatted.
+    return $output_data;
+};
+
 # ---------------------------------------------------------------------------- #
 # Function format_output()                                                     #
 # ---------------------------------------------------------------------------- #
